@@ -4,9 +4,9 @@ import uuid
 
 class WaterControl(BaseDevice):
 
-    def __init__(self, smart_system, device_map):
+    def __init__(self, location, device_map):
         """Constructor for the water control device."""
-        BaseDevice.__init__(self, smart_system, device_map["COMMON"][0]["id"])
+        BaseDevice.__init__(self, location, device_map["COMMON"][0]["id"])
         self.type = "WATER_CONTROL"
         self.valve_set_id = "N/A"
         self.valve_id = "N/A"
@@ -30,7 +30,7 @@ class WaterControl(BaseDevice):
             "type": "VALVE_CONTROL",
             "attributes": {"command": "START_SECONDS_TO_OVERRIDE", "seconds": duration},
         }
-        self.smart_system.call_smart_system_service(self.valve_id, data)
+        self.location.smart_system.call_smart_system_service(self.valve_id, data)
 
     def stop_until_next_task(self):
         data = {
@@ -38,7 +38,7 @@ class WaterControl(BaseDevice):
             "type": "VALVE_CONTROL",
             "attributes": {"command": "STOP_UNTIL_NEXT_TASK"},
         }
-        self.smart_system.call_smart_system_service(self.valve_id, data)
+        self.location.smart_system.call_smart_system_service(self.valve_id, data)
 
     def pause(self):
         data = {
@@ -46,7 +46,7 @@ class WaterControl(BaseDevice):
             "type": "VALVE_CONTROL",
             "attributes": {"command": "PAUSE"},
         }
-        self.smart_system.call_smart_system_service(self.valve_id, data)
+        self.location.smart_system.call_smart_system_service(self.valve_id, data)
 
     def unpause(self):
         data = {
@@ -54,4 +54,4 @@ class WaterControl(BaseDevice):
             "type": "VALVE_CONTROL",
             "attributes": {"command": "UNPAUSE"},
         }
-        self.smart_system.call_smart_system_service(self.valve_id, data)
+        self.location.smart_system.call_smart_system_service(self.valve_id, data)
